@@ -27,10 +27,8 @@
 #include <string.h>
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
-#include <libgnomeui/gnome-about.h>
 #include <gconf/gconf-client.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-help.h>
 
 #include "netstatus-icon.h"
 #include "netstatus-iface.h"
@@ -53,6 +51,8 @@ static void     netstatus_applet_instance_init             (NetstatusApplet
 							    NetstatusAppletClass      *klass);
 static void     netstatus_applet_class_init                (NetstatusAppletClass      *klass);
 static void     netstatus_applet_finalize                  (GObject                   *object);
+static gboolean	netstatus_applet_button_press_event	   (GtkWidget		      *widget,
+							    GdkEventButton	      *event);
 static gboolean netstatus_applet_key_press_event           (GtkWidget                 *widget,
 							    GdkEventKey               *event);
 static void     netstatus_applet_orientation_changed       (NetstatusApplet           *applet,
@@ -156,6 +156,7 @@ netstatus_applet_class_init (NetstatusAppletClass *klass)
   gobject_class->finalize = netstatus_applet_finalize;
 
   widget_class->key_press_event = netstatus_applet_key_press_event;
+  widget_class->button_press_event = netstatus_applet_button_press_event;
 }
 
 static void
@@ -189,6 +190,21 @@ netstatus_applet_finalize (GObject *object)
   parent_class->finalize (object);
 }
 
+static gboolean
+netstatus_applet_button_press_event (GtkWidget	    *widget,
+				     GdkEventButton *event)
+{
+  NetstatusApplet *applet = (NetstatusApplet *) widget;
+
+  if (event->button == 1)
+    {
+      netstatus_icon_invoke (NETSTATUS_ICON (applet->priv->icon));
+      return TRUE;
+    }
+
+  return GTK_WIDGET_CLASS (parent_class)->button_press_event (widget, event);
+}
+
 static gboolean
 netstatus_applet_key_press_event (GtkWidget   *widget,
 				  GdkEventKey *event)
@@ -249,9 +265,10 @@ netstatus_applet_display_help (BonoboUIComponent *uic,
 {
   GError *error = NULL;
   
-  gnome_help_display_on_screen ("gnome-netstatus", NULL,
-				gtk_widget_get_screen (GTK_WIDGET (applet)),
-				&error);
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+		"ghelp:gnome-netstatus",
+		gtk_get_current_event_time (),
+		&error);
   if (error)
     {
       GtkWidget *message_dialog;
@@ -259,7 +276,7 @@ netstatus_applet_display_help (BonoboUIComponent *uic,
 					       0,
 					       GTK_MESSAGE_ERROR,
 					       GTK_BUTTONS_OK,
-					       _("There was an error displaying help: %s"),
+					       _("There was an error displaying help:\n%s"),
 					       error->message);
       g_error_free (error);
       gtk_window_set_screen (GTK_WINDOW (message_dialog),
@@ -280,42 +297,16 @@ netstatus_applet_display_about_dialog (BonoboUIComponent *uic,
       "Calum Benson <calum.benson@sun.com>",
       NULL
     };
-  const char *documenters [] = { NULL };
-  const char *translator_credits = _("translator_credits");
 
-  GdkPixbuf *pixbuf = NULL;
-
-  if (applet->priv->about_dialog)
-    {
-      gtk_window_set_screen (GTK_WINDOW (applet->priv->about_dialog),
-			     gtk_widget_get_screen (GTK_WIDGET (applet)));
-      gtk_window_present (GTK_WINDOW (applet->priv->about_dialog));
-      return;
-    }
-
-  applet->priv->about_dialog =
-       g_object_new (GTK_TYPE_ABOUT_DIALOG,
-                     "name", _("Network Monitor"), 
-                     "version", VERSION,
-		     "copyright", "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n",
-		     "comments", _("The Network Monitor displays the status of a network device."),
-		     "authors", authors,
-		     "documenters", documenters,
-		     "translator-credits", translator_credits,
-		     "logo", pixbuf,
-                     NULL);
-
-  gtk_window_set_wmclass (GTK_WINDOW (applet->priv->about_dialog), "netstatus", "Netstatus");
-  gtk_window_set_screen (GTK_WINDOW (applet->priv->about_dialog),
-			 gtk_widget_get_screen (GTK_WIDGET (applet)));
-
-  gtk_window_set_icon_name(GTK_WINDOW (applet->priv->about_dialog), "gnome-netstatus-tx");
-
-  g_signal_connect (applet->priv->about_dialog,
-		    "destroy",
-		    G_CALLBACK (gtk_widget_destroyed),
-		    &applet->priv->about_dialog);
-  gtk_widget_show (applet->priv->about_dialog);
+  gtk_show_about_dialog (NULL,
+	     "program-name", _("Network Monitor"),
+	     "version", VERSION,
+	     "copyright", "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.",
+	     "comments", _("The Network Monitor displays the status of a network device."),
+	     "authors", authors,
+	     "translator-credits", _("translator-credits"),
+	     "logo-icon-name", "gnome-netstatus-rx",
+	     NULL);
 }
 
 static void
