@@ -27,8 +27,7 @@
 
 #include <string.h>
 #include <glade/glade-xml.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-help.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 
 #include "netstatus-icon.h"
@@ -119,7 +118,7 @@ netstatus_dialog_update_name (NetstatusDialogData *data)
     }
   
   UNKNOWN_STR (text, iface_name);
-  gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (data->name)->entry), text);
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (data->name))), text);
 }
 
 static inline void
@@ -373,11 +372,11 @@ netstatus_dialog_response (GtkWidget *dialog,
     case GTK_RESPONSE_HELP:
       {
 	GError    *error = NULL;
-	GdkScreen *screen;
 
-	screen = gtk_window_get_screen (GTK_WINDOW (dialog));
-
-	gnome_help_display_on_screen ("gnome-netstatus", "gnome-netstatus-props", screen, &error);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+			"ghelp:gnome-netstatus?gnome-netstatus-props",
+			gtk_get_current_event_time (),
+			&error);
 
 	if (error)
 	  {
@@ -391,7 +390,8 @@ netstatus_dialog_response (GtkWidget *dialog,
 						     error->message);
 
 	    gtk_window_set_resizable (GTK_WINDOW (message_dialog), FALSE);
-	    gtk_window_set_screen (GTK_WINDOW (message_dialog), screen);
+	    gtk_window_set_screen (GTK_WINDOW (message_dialog),
+			    gtk_widget_get_screen (GTK_WIDGET (dialog)));
 	    
 	    g_signal_connect (message_dialog, "response",
 			      G_CALLBACK (gtk_widget_destroy),
@@ -619,7 +619,7 @@ netstatus_dialog_setup_connection (NetstatusDialogData *data,
 
   data->icon = NETSTATUS_ICON (icon);
 
-  data->name   = glade_xml_get_widget (xml, "name_combo");
+  data->name   = glade_xml_get_widget (xml, "name_combo_box_entry");
   data->status = glade_xml_get_widget (xml, "status_label");
 
   netstatus_dialog_update_name (data);
@@ -679,7 +679,7 @@ static gboolean
 netstatus_dialog_iface_list_monitor (NetstatusDialogData *data)
 {
   GList *iface_names, *l;
-  int    n_ifaces;
+  int    n_ifaces, i;
 
   iface_names = netstatus_list_interface_names (NULL);
 
@@ -687,13 +687,18 @@ netstatus_dialog_iface_list_monitor (NetstatusDialogData *data)
 
   if (data->n_ifaces != n_ifaces)
     {
-      g_signal_handlers_block_by_func (GTK_COMBO (data->name)->entry,
+      g_signal_handlers_block_by_func (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (data->name))),
 				       G_CALLBACK (netstatus_dialog_set_iface_name), data);
-				       
-      gtk_combo_set_popdown_strings (GTK_COMBO (data->name), iface_names);
+      i = gtk_tree_model_iter_n_children (gtk_combo_box_get_model (GTK_COMBO_BOX (data->name)), NULL);
+      while (i > 0)
+        gtk_combo_box_remove_text (GTK_COMBO_BOX (data->name), --i);
+
+      for (l = iface_names; l; l = l->next)
+        gtk_combo_box_append_text (GTK_COMBO_BOX (data->name), l->data);
+
       netstatus_dialog_update_name (data);
 
-      g_signal_handlers_unblock_by_func (GTK_COMBO (data->name)->entry,
+      g_signal_handlers_unblock_by_func (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (data->name))),
 					 G_CALLBACK (netstatus_dialog_set_iface_name), data);
     }
 
@@ -772,7 +777,7 @@ netstatus_dialog_new (NetstatusIface *iface)
 					    data);
   netstatus_dialog_iface_list_monitor (data);
 
-  g_signal_connect_swapped (GTK_COMBO (data->name)->entry, "changed",
+  g_signal_connect_swapped (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (data->name))), "changed",
 			    G_CALLBACK (netstatus_dialog_set_iface_name),
 			    data);
   g_object_unref (xml);
