@@ -31,7 +31,7 @@
 
 #include "netstatus-iface.h"
 
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <sys/types.h>
 #include <sys/ioctl.h>
