@@ -65,13 +65,8 @@ G_CONST_RETURN char *  netstatus_iface_get_name              (NetstatusIface  *i
 void                   netstatus_iface_set_name              (NetstatusIface  *iface,
 							      const char      *name);
 NetstatusState         netstatus_iface_get_state             (NetstatusIface  *iface);
-
-void                   netstatus_iface_get_packet_statistics (NetstatusIface  *iface,
-							      long            *in,
-							      long            *out);
-void                   netstatus_iface_get_byte_statistics   (NetstatusIface  *iface,
-							      long            *in,
-							      long            *out);
+void                   netstatus_iface_get_statistics        (NetstatusIface  *iface,
+							      NetstatusStats  *stats);
 gboolean               netstatus_iface_get_is_wireless       (NetstatusIface  *iface);
 int                    netstatus_iface_get_signal_strength   (NetstatusIface  *iface);
 
